==> nextcloud-27.1.5.tgz: nextcloud/apps/updatenotification/l10n/fa.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version} آماده است. برای چگونگی بروزرسانی اطلاعات بیشتر را دریافت نمایید.",
    "Channel updated" : "کانال به‌روز شد",
    "Web updater is disabled" : "Web updater is disabled",
    "Update notifications" : "Update notifications",
    "The update server could not be reached since %d days to check for new updates." : "The update server could not be reached since %d days to check for new updates.",
    "Please check the Nextcloud and server log files for errors." : "Please check the Nextcloud and server log files for errors.",
    "Update to %1$s is available." : "به‌روزرسانی به %1$s موجود است.",
    "Update to {serverAndVersion} is available." : "Update to {serverAndVersion} is available.",
    "Update for {app} to version %s is available." : "Update for {app} to version %s is available.",
    "Update notification" : "به‌روزرسانی اعلان",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Displays update notifications for Nextcloud and provides the SSO for the updater.",
    "Update" : "یه‌روزرسانی",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible.",
    "Apps missing compatible version" : "Apps missing compatible version",
    "View in store" : "نمایش در فروشگاه",
    "Apps with compatible version" : "Apps with compatible version",
    "Please note that the web updater is not recommended with more than 100 users! Please use the command line updater instead!" : "Please note that the web updater is not recommended with more than 100 users! Please use the command line updater instead!",
    "Open updater" : "باز کردن به‌روزرسان",
    "Download now" : "Download now",
    "What's new?" : "What's new?",
    "View changelog" : "مشاهده تغییرات",
    "The update check is not yet finished. Please refresh the page." : "The update check is not yet finished. Please refresh the page.",
    "Your version is up to date." : "Your version is up to date.",
    "A non-default update server is in use to be checked for updates:" : "A non-default update server is in use to be checked for updates:",
    "Update channel" : "Update channel",
    "Changing the update channel also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "Changing the update channel also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page.",
    "Current update channel:" : "Current update channel:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "You can always update to a newer version. But you can never downgrade to a more stable version.",
    "Notify members of the following groups about available updates:" : "Notify members of the following groups about available updates:",
    "No groups" : "No groups",
    "Only notifications for app updates are available." : "Only notifications for app updates are available.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "The selected update channel makes dedicated notifications for the server obsolete.",
    "The selected update channel does not support updates of the server." : "The selected update channel does not support updates of the server.",
    "A new version is available: <strong>{newVersionString}</strong>" : "A new version is available: <strong>{newVersionString}</strong>",
    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}",
    "Checked on {lastCheckedDate}" : "Checked on {lastCheckedDate}",
    "Checking apps for compatible versions" : "Checking apps for compatible versions",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false.",
    "Could not connect to the App Store or no updates have been returned at all. Search manually for updates or make sure your server has access to the internet and can connect to the App Store." : "Could not connect to the App Store or no updates have been returned at all. Search manually for updates or make sure your server has access to the internet and can connect to the App Store.",
    "<strong>All</strong> apps have a compatible version for this Nextcloud version available." : "<strong>All</strong> apps have a compatible version for this Nextcloud version available.",
    "Enterprise" : "Enterprise",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package.",
    "Stable" : "Stable",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "The most recent stable version. It is suited for regular use and will always update to the latest major version.",
    "Beta" : "بتا",
    "A pre-release version only for testing new features, not for production environments." : "A pre-release version only for testing new features, not for production environments.",
    "_<strong>%n</strong> app has no compatible version for this Nextcloud version available._::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available._" : ["<strong>%n</strong> app has no compatible version for this Nextcloud version available.","<strong>%n</strong> apps have no compatible version for this Nextcloud version available."],
    "Please use the command line updater to update." : "Please use the command line updater to update.",
    "You can change the update channel below which also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "You can change the update channel below which also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page.",
    "Update channel:" : "کانال به‌روزرسانی"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-27.1.11.tgz: nextcloud/apps/updatenotification/l10n/fa.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version} آماده است. برای چگونگی بروزرسانی اطلاعات بیشتر را دریافت نمایید.",
    "Channel updated" : "کانال به‌روز شد",
    "Web updater is disabled" : "Web updater is disabled",
    "Update notifications" : "Update notifications",
    "The update server could not be reached since %d days to check for new updates." : "The update server could not be reached since %d days to check for new updates.",
    "Please check the Nextcloud and server log files for errors." : "Please check the Nextcloud and server log files for errors.",
    "Update to {serverAndVersion} is available." : "Update to {serverAndVersion} is available.",
    "Update for {app} to version %s is available." : "Update for {app} to version %s is available.",
    "Update notification" : "به‌روزرسانی اعلان",
    "Update" : "به‌روزرسانی",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible.",
    "Apps missing compatible version" : "Apps missing compatible version",
    "View in store" : "نمایش در فروشگاه",
    "Apps with compatible version" : "Apps with compatible version",
    "Open updater" : "باز کردن به‌روزرسان",
    "Download now" : "Download now",
    "What's new?" : "What's new?",
    "View changelog" : "مشاهده تغییرات",
    "The update check is not yet finished. Please refresh the page." : "The update check is not yet finished. Please refresh the page.",
    "Your version is up to date." : "نسخهٔ شما به‌روز است.",
    "A non-default update server is in use to be checked for updates:" : "A non-default update server is in use to be checked for updates:",
    "Update channel" : "کانال به‌روزرسانی",
    "Changing the update channel also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "Changing the update channel also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page.",
    "Current update channel:" : "کانال به‌روزرسانی جاری:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "You can always update to a newer version. But you can never downgrade to a more stable version.",
    "Notify members of the following groups about available updates:" : "Notify members of the following groups about available updates:",
    "No groups" : "No groups",
    "Only notifications for app updates are available." : "Only notifications for app updates are available.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "The selected update channel makes dedicated notifications for the server obsolete.",
    "The selected update channel does not support updates of the server." : "The selected update channel does not support updates of the server.",
    "A new version is available: <strong>{newVersionString}</strong>" : "A new version is available: <strong>{newVersionString}</strong>",
    "Checking apps for compatible versions" : "Checking apps for compatible versions",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false.",
    "Could not connect to the App Store or no updates have been returned at all. Search manually for updates or make sure your server has access to the internet and can connect to the App Store." : "Could not connect to the App Store or no updates have been returned at all. Search manually for updates or make sure your server has access to the internet and can connect to the App Store.",
    "<strong>All</strong> apps have a compatible version for this Nextcloud version available." : "<strong>All</strong> apps have a compatible version for this Nextcloud version available.",
    "Enterprise" : "Enterprise",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package.",
    "Stable" : "Stable",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "The most recent stable version. It is suited for regular use and will always update to the latest major version.",
    "Beta" : "بتا",
    "A pre-release version only for testing new features, not for production environments." : "A pre-release version only for testing new features, not for production environments.",
    "_<strong>%n</strong> app has no compatible version for this Nextcloud version available._::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available._" : ["<strong>%n</strong> app has no compatible version for this Nextcloud version available.","<strong>%n</strong> apps have no compatible version for this Nextcloud version available."],
    "Update to %1$s is available." : "به‌روزرسانی به %1$s موجود است.",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Displays update notifications for Nextcloud and provides the SSO for the updater.",
    "Please note that the web updater is not recommended with more than 100 users! Please use the command line updater instead!" : "Please note that the web updater is not recommended with more than 100 users! Please use the command line updater instead!",
    "Please use the command line updater to update." : "Please use the command line updater to update.",
    "You can change the update channel below which also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "You can change the update channel below which also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page.",
    "Update channel:" : "کانال به‌روزرسانی",
    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}",
    "Checked on {lastCheckedDate}" : "Checked on {lastCheckedDate}"
},
"nplurals=2; plural=(n > 1);");
